@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
 
-from pkg_resources import require
 from mc_mod_getter import __project_urls__
 from mc_mod_getter.utils.ApiHandler import ApiHandler
 from pathlib import Path
@@ -10,7 +9,7 @@ import yaml
 
 
 @click.command()
-@click.option('--file','-f', help='Path to mod yaml file',type=click.Path(exists=True), required=True)
+@click.option('--file','-f', help='Path to mod yaml file', type=click.Path(exists=True), required=True)
 @click.option('--verbose','-v', help='Verbose mode', is_flag=True)
 def main(file,verbose):
     # TODO: Possibly get yaml from gui but thats extra work :/
@@ -23,17 +22,19 @@ def main(file,verbose):
 
     mods_dict = yaml.safe_load(open(mods_yaml, 'r')).items()
     
-    for host, mods in mods_dict:
-        download_dir = mods.get('mmc_dir', str(Path.home() / 'Downloads'))
-        logging.info(f'Downloading mods to: {download_dir}')
+    for host, mod_info in mods_dict:
+        mod_list = mod_info.pop('mods')
 
-        api_handler = ApiHandler(host, mods['version'], mods['loader'], download_dir, verbose)
+        if not mod_info.get('mod_dir',None):
+            mod_info['mod_dir'] = str(Path.home() / 'Downloads')
 
-        for mod in mods['mods']:
+        logging.info(f'Downloading mods to: {mod_info["mod_dir"]}')
+
+        api_handler = ApiHandler(host, **mod_info)
+
+        for mod in mod_list:
             api_handler.download_mod(mod)
 
 
 if __name__ == '__main__':
     main()
-
-    
\ No newline at end of file
